cd "D:\Download in D\NLSY79"

*** Hourly Wage Variables: HOURLY RATE OF PAY CURRENT/MOST RECENT JOB ***

clear 

use "HourlyWage_CurrentJob.dta"

drop sample_id_1979 sample_race_78scrn sample_sex_1979

reshape long cpshrp_, i(caseid_1979) j(year)

replace cpshrp_=. if cpshrp_==-5  // - NON-INTERVIEW
replace cpshrp_=. if cpshrp_==-4  // - VALID SKIP
replace cpshrp_=. if cpshrp_==-3  // - Invalid Skip
replace cpshrp_=. if cpshrp_==-2  // - Don't Know
replace cpshrp_=. if cpshrp_==-1  // - Refusal

bysort caseid_1979: gen count=_N
tab count //16 years total for all individuals
drop count

rename cpshrp_ HourlyWage_CurrentJob
label variable HourlyWage_CurrentJob "HOURLY RATE OF PAY CURRENT/MOST RECENT JOB"

/*
Total N*T = 342,522
count if HourlyWage_CurrentJob==. // 78,561
count if HourlyWage_CurrentJob==0 // 15

preserve

gen index=1 if HourlyWage_CurrentJob!=.
bys caseid_1979: egen N_years=sum( index )
drop index 

* how many obs with no missing HourlyWage_CurrentJob? 1,058 individuals 

preserve
collapse N_years, by(caseid_1979)
tab N_years
restore 

restore
*/

save HourlyWage_CurrentJob_Cleaned, replace

merge 1:1 caseid_1979 year using HourlyWage_HoursWorked 
/*
    Result                           # of obs.
    -----------------------------------------
    not matched                       139,546
        from master                         0  (_merge==1)   
        from using                    139,546  (_merge==2)  -> 1996, 1998, ..., 2016 Current Job NOT available
 
    matched                           202,976  (_merge==3)  -> 1979-1994 Current Job available
    -----------------------------------------
*/
*drop _merge
sort caseid_1979 year

corr HourlyWage_CurrentJob HourlyWage1
corr HourlyWage_CurrentJob HourlyWage2
corr HourlyWage_CurrentJob HourlyWage3
corr HourlyWage_CurrentJob HourlyWage4
corr HourlyWage_CurrentJob HourlyWage5
corr HourlyWage_CurrentJob HourlyWage1 HourlyWage2 HourlyWage3 HourlyWage4 HourlyWage5

* Generate Hours adjusted Wage: 

egen HoursWorked =rowtotal(HoursWorked1_A HoursWorked2_A HoursWorked3_A HoursWorked4_A HoursWorked5_A)

gen HoursWorked1_frac = HoursWorked1_A / HoursWorked
gen HoursWorked2_frac = HoursWorked2_A / HoursWorked
gen HoursWorked3_frac = HoursWorked3_A / HoursWorked
gen HoursWorked4_frac = HoursWorked4_A / HoursWorked
gen HoursWorked5_frac = HoursWorked5_A / HoursWorked

gen HourlyWage1_Adjusted = HourlyWage1 * HoursWorked1_frac
gen HourlyWage2_Adjusted = HourlyWage2 * HoursWorked2_frac
gen HourlyWage3_Adjusted = HourlyWage3 * HoursWorked3_frac
gen HourlyWage4_Adjusted = HourlyWage4 * HoursWorked4_frac
gen HourlyWage5_Adjusted = HourlyWage5 * HoursWorked5_frac

egen HourlyWage_Adjusted = rowtotal(HourlyWage1_Adjusted HourlyWage2_Adjusted HourlyWage3_Adjusted HourlyWage4_Adjusted HourlyWage5_Adjusted)
replace HourlyWage_Adjusted = . if HourlyWage1_Adjusted==. & HourlyWage2_Adjusted==. & HourlyWage3_Adjusted==. & HourlyWage4_Adjusted==. & HourlyWage5_Adjusted==. 

corr HourlyWage_CurrentJob HourlyWage_Adjusted

* Total N*T = 342,522

* Job 1: Reported both Hourly Wage & Hours Worked (Case 1) 
count if HoursWorked1_A!=. & HourlyWage1!=.
* Job 1: Reported Hourly Wage BUT NOT Hours Worked (Case 2) 
count if HoursWorked1_A==. & HourlyWage1!=.
* Job 1: Didn't reported Hourly Wage BUT reported Hours Worked (Case 3)   
count if HoursWorked1_A!=. & HourlyWage1==.
* Job 1: Didn't reported Hourly Wage & Hours Worked (Case 4)   
count if HoursWorked1_A==. & HourlyWage1==.

* Case 2: 

count if HoursWorked1_A==. & HourlyWage1!=.
count if HoursWorked2_A==. & HourlyWage2!=.
count if HoursWorked3_A==. & HourlyWage3!=.
count if HoursWorked4_A==. & HourlyWage4!=.
count if HoursWorked5_A==. & HourlyWage5!=.
